/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.communication
 * File:    Usermanager.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.communication;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.HashMap;
import java.util.Properties;

import org.apache.log4j.Logger;

import de.fhhannover.inform.iron.mapserver.logging.Logging;

/**
 * The {@link Usermanager} performs the authentication of users based upon the
 * <code>user.properties</code> configuration file.
 * 
 * @author Waldemar Bender
 * @author Dennis Ludewig
 *
 */
public class Usermanager extends Properties {
	//FIXME refactor this class !
	private static final long serialVersionUID = -4859060526104700808L;
	
	/**
	 * Singleton
	 */
	private static Usermanager mConfReader;
	
	/**
	 * This map holds the relations between a map clients name (aka the username)
	 * and the instance of the {@link Client} implementation.
	 * 
	 * FIXME This map is actually not used?!
	 */
	private HashMap<String, Client> mRelation = new HashMap<String,Client>();
	
	private static final String PROP_PATH = "user.properties";
	
	/**
	 * The logger
	 */
	private static Logger logger;
	static {
		logger = Logging.getTheLogger();
	}
	
	/**
	 * Singleton
	 * @return
	 */
	public static synchronized Usermanager getInstance() {
		if (mConfReader == null) {
			mConfReader = new Usermanager();
		}
		return mConfReader;
	}
	
	/**
	 * Default constructor. Parses the <code>user.properties</code> file.
	 */
	private Usermanager() {
		try {
			FileReader mPropFile = new FileReader(PROP_PATH);
			this.load(mPropFile);
			mPropFile.close();
		} catch (FileNotFoundException e) {
			logger.warn("could not find user.properties file in current directory");
			e.printStackTrace();
		} catch (IOException e) {
			logger.warn("IO error when reading user.properties file");
			e.printStackTrace();
		}
	}
	
	/**
	 * Just compares the password as string
	 * @param name
	 * @param pass
	 * @return
	 */
	public boolean checkBasicAuth(String name, String pass) {
		String passFile = getProperty(name);
		if(pass.equals(passFile)) {
			logger.info("Accepted basic client " + name);
			return true;
		} else {
			logger.info("Rejected basic client " + name);
			return false;
		}
	}
	
	/**
	 * Get client for provided username. Username refers to the appropriate
	 * map client.
	 * 
	 * @param username
	 * @return
	 * 
	 */
	public synchronized Client getClient (String username){
		//FIXME make shorter
		Client client;
		if ( (client = mRelation.get(username)) != null){
			return client;
		}else{
			return null;
		}
	}
	
	/**
	 * 
	 * @param user
	 * @param pw
	 * @param client
	 * @return
	 */
	public synchronized boolean addClient (String user, String pw, Client client){
		// TODO implement this method
		return true;
	}
	
	/**
	 * 
	 * @param dn
	 * @param client
	 */
	public synchronized void addClient (String dn, Client client){
		// TODO implement this method
	}
}
