/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.communication.services.ssrc
 * File:    SubscribeReceive.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.communication.services.ssrc;

import java.security.NoSuchAlgorithmException;

import org.apache.log4j.Logger;
import org.trustedcomputinggroup._2010.ifmap._2.ResponseType;
import org.trustedcomputinggroup._2010.ifmap._2.SubscribeRequestType;
import org.trustedcomputinggroup._2010.ifmap._2.ResponseType.SubscribeReceived;

import de.fhhannover.inform.iron.mapserver.communication.DeprecatedDataModelServiceAccessor;
import de.fhhannover.inform.iron.mapserver.communication.connections.ConnectionContainer;
import de.fhhannover.inform.iron.mapserver.communication.services.ssrc.exceptions.SessionNotFoundException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.AlreadyObservedException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.IdentifierConstructionException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.NoSuchPublisherException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.NoSuchSubscriptionException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.ParameterException;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.RequestCreationException;
import de.fhhannover.inform.iron.mapserver.logging.Logging;
import de.fhhannover.inform.iron.mapserver.messages.SubscriptionRequest;
import de.fhhannover.inform.iron.mapserver.utils.MessageTransformer;

/**
 * SearchReceive class
 * 
 * Manages the subscribe requests and pass the subscribes to the data model
 * 
 * @author Waldemar Bender
 * @version 0.1
 * 
 * created: 27.05.2010
 *
 * changes:
 *
 */


public class SubscribeReceive {
	
	private static SubscribeObserverConnection soc;
	

	private static Logger logger;
	static {
		logger = Logging.getTheLogger();
		soc = new SubscribeObserverConnection();
		try {
			DeprecatedDataModelServiceAccessor.getDataModelServiceInstance().registerSubscriptionObserver(soc);
		} catch (AlreadyObservedException e) {
			// static initializer, should not occur
			e.printStackTrace();
		}
	}
	
	
	public static ResponseType Subscribe(SubscribeRequestType srt) throws 
				NoSuchAlgorithmException, SessionNotFoundException, RequestCreationException, IdentifierConstructionException,
				ParameterException, NoSuchPublisherException, NoSuchSubscriptionException {
		ConnectionContainer.getInstance().renewSession(srt.getSessionId());
		
		MessageTransformer mTrans = MessageTransformer.getInstance();
		SubscriptionRequest subscripeReq = mTrans.transformSubscribeRequest(srt);
		
		DeprecatedDataModelServiceAccessor.getDataModelServiceInstance().subscribe(subscripeReq);
		

		ResponseType rt = new ResponseType();
		rt.setSubscribeReceived(new SubscribeReceived());
		return rt;
	}
		


}
