/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.messages
 * File:    NewSessionRequest.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.messages;

import java.math.BigInteger;

import de.fhhannover.inform.iron.mapserver.configuration.datamodel.ConfigurationManager;
import de.fhhannover.inform.iron.mapserver.datamodel.DataModelService;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.RequestCreationException;

/**
 * A request that needs to be given to the {@link DataModelService} if a
 * MAPC creates a new connection.
 * 
 * @author aw
 * @version 0.1
 * 
 * 
 * created: 05.12.09
 * changes:
 * 	05.12.09 aw - Created class, well it was created before by wb, but he
 * 		didn't comment that.
 * 
 *	17.12.09 aw - Constructors will throw exceptions.
 *  05.02.10 aw - Changed exception to RequestCreationException,
 *                use Request superclass
 *
 */
public class NewSessionRequest extends Request {
 
	private String publisherId;
	
	private BigInteger maxPollSize;
	
	NewSessionRequest(String sessionid, String publisherid,
				BigInteger maxpollsize) throws RequestCreationException {
		super(sessionid);
		
		if (publisherid == null || publisherid.length() == 0) {
			throw new RequestCreationException("publisherId needs to be set");
		}
		
		this.publisherId = new String(publisherid);
		
		if (maxpollsize != null) {
			this.maxPollSize = new BigInteger(maxpollsize.toString());
		} else {
			this.maxPollSize =
				new BigInteger(ConfigurationManager.
						getInstance().getDefaultPollSize().toString());
		}
	}
	
	NewSessionRequest(String sessionid, String publisherid)
									throws RequestCreationException {
		this(sessionid, publisherid, null);
	}
	
	public String getPublisherid() {
		return new String(publisherId);
	}
	
	public BigInteger getMaxPollSize() {
		return new BigInteger(maxPollSize.toString());
	}
	 
}
 
