/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.messages
 * File:    PublishUpdate.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.messages;

import java.util.List;

import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.RequestCreationException;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.Identifier;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.meta.MetaLifeTimeType;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.meta.Metadata;

/**
 * This class needs to be encapsulated into a {@link PublishUpdate}.
 * 
 * @author awe, vp
 * @version 0.1
 */


/* created: 19.11.09
 * changes:
 *	22.11.09 vp - Added methods: 
 * 		getter and setter for lifetime, setMetadataList()
 *	28.11.09 aw - Created lots of constructors, removed Lifetime Type in favor
 *		for MetaLifeTimeType
 *	05.12.09 aw - Made setter for lifetime deprecated as it should be given in
 *		a constructor
 *  04.02.10 aw - Added timestamp
 *  10.02.10 aw - Cleaned up...
 *  
 *  thoughs:
 *   - We do not copy the metadataList?
 */
public class PublishUpdate extends SubPublishRequest {
 
	private MetaLifeTimeType lifetime;
	private List<Metadata> metadataList;
	private String timeStamp;
	
	/**
	 * Create a PublishUpdate object (PublishUpdateRequest) with every
	 * possible parameter.
	 * 
	 * @param ident1
	 * @param ident2
	 * @param ml
	 * @param lt
	 * @throws RequestCreationException
	 */
	PublishUpdate(Identifier ident1, Identifier ident2, List<Metadata> ml,
			MetaLifeTimeType lt, String timestamp)
	throws RequestCreationException {
		super(ident1, ident2);
		
		if (timestamp == null)
			throw new RequestCreationException("Timestamp is null");
		
		if (timestamp.length() == 0)
			throw new RequestCreationException("Timestamp is empty");
		
		if (ml == null)
			throw new RequestCreationException("Metadata List is null");
		
		if (ml.size() == 0) {
			throw new RequestCreationException("Metadata List is empty");
		}
		this.timeStamp = new String(timestamp);
		this.metadataList = ml;
		this.lifetime = lt;
	}
	
	/**
	 * Construct a PublishUpdate with default session lifetime.
	 * 
	 * @param ident1
	 * @param ident2
	 * @param ml
	 * @throws RequestCreationException
	 */
	PublishUpdate(Identifier ident1, Identifier ident2, List<Metadata> ml,
			String timestamp) throws RequestCreationException {
		this(ident1, ident2, ml, MetaLifeTimeType.session, timestamp);
	}
	
	/**
	 * Construct a PublishUpdate with only one identifier.
	 * 
	 * @param ident1
	 * @param ml
	 * @param lt
	 * @throws RequestCreationException
	 */
	PublishUpdate(Identifier ident1, List<Metadata> ml, MetaLifeTimeType lt,
			String timestamp) throws RequestCreationException {
		this(ident1, null, ml, lt, timestamp);
	}
	
	/**
	 * Construct a PublishUpdate with only one identifier and session
	 * lifetime.
	 * 
	 * @param ident1
	 * @param ml
	 * @throws RequestCreationException
	 */
	PublishUpdate(Identifier ident1, List<Metadata> ml,
			String timestamp) throws RequestCreationException {
		this(ident1, ml, MetaLifeTimeType.session, timestamp);
	}
	
	public List<Metadata> getMetadataList() {
		return metadataList;
	}

	public MetaLifeTimeType getLifeTime() {
		return lifetime;
	}

	public String getTimestamp() {	
		return new String(timeStamp);
	}
}
 

