/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.messages
 * File:    RequestFactory.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.messages;

import java.math.BigInteger;
import java.util.List;

import de.fhhannover.inform.iron.mapserver.datamodel.DataModelService;
import de.fhhannover.inform.iron.mapserver.datamodel.Filter;
import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.RequestCreationException;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.Identifier;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.meta.MetaLifeTimeType;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.meta.Metadata;

/**
 * A factory to create all possible {@link Request} subtypes to be given
 * to the {@link DataModelService}
 * 
 * @author aw
 * @version 0.1
 * 
 */
/*
 * 
 * created: 05.02.10
 * 
 * changes:
 *  05.02.10 - 08.06.10 aw, vp - extended to support subscription functionality
 *
 */
public class RequestFactory {
	
	private static RequestFactory instance;
	
	private RequestFactory() {
		
	}
	
	
	public static RequestFactory getInstance() {
		if (instance == null) {
			instance = new RequestFactory();
		}
		return instance;
	}
	
		 
	public PublishRequest createPublishRequest(String sessionid,
			List<SubPublishRequest> slist) throws RequestCreationException {
		PublishRequest pr = new PublishRequest(sessionid, slist);
		return pr;
	}
	 
	public SubPublishRequest createPublishUpdateRequest(Identifier i1,
			Identifier i2, List<Metadata> metadatalist, MetaLifeTimeType lt,
			String timestamp) throws RequestCreationException {

		return new PublishUpdate(i1, i2, metadatalist, lt, timestamp);
	}
	
	 
	public SearchRequest createSearchRequest(String sessionid, int maxDepth,
		int maxResultSize, String terminalIdentTypes, Identifier start,
		Filter matchLinksFilter, Filter resultFilter) throws RequestCreationException {
	
		return new SearchRequest(sessionid, maxDepth, maxResultSize,
				terminalIdentTypes, start, matchLinksFilter, resultFilter);
	}
	

	 
	public SubPublishRequest createPublishDeleteRequest(Identifier i1,
					Identifier i2, Filter f) throws RequestCreationException {
	
		return new PublishDelete(i1, i2, f);
	}
	 
	public PurgePublisherRequest createPurgePublisherRequest(String sessionid,
			String publisherid) throws RequestCreationException {
	
		return new PurgePublisherRequest(sessionid, publisherid);
	}
	 
	public NewSessionRequest createNewSessionRequest(String sessionid,
			String publisherid, BigInteger maxpollsize) throws RequestCreationException {
		return new NewSessionRequest(sessionid, publisherid, maxpollsize);
	}
	 
	public NewSessionRequest createNewSessionRequest(String sessionid,
			String publisherid) throws RequestCreationException {
		return new NewSessionRequest(sessionid, publisherid);
	}
	public EndSessionRequest createEndSessionRequest(String sessionid)
			throws RequestCreationException {
		return new EndSessionRequest(sessionid);
	}
	
	public SubscriptionRequest createSubscriptionRequest(String sessionId,
			List<SubSubscriptionRequest> ssrlist) throws RequestCreationException {
		
		return new SubscriptionRequest(sessionId, ssrlist);
	}
	
	public SubSubscriptionRequest createSubscriptionDelete(String name)
												throws RequestCreationException {
		return new SubscriptionDelete(name);
	}
	
	public SubSubscriptionRequest createSubscriptionUpdate(String name, SearchRequest searchRequest)
	throws RequestCreationException {
		return new SubscriptionUpdate(name, searchRequest);
	}


	public SubPublishRequest createPublishUpdateRequest(Identifier i,
			List<Metadata> metadatalist, MetaLifeTimeType lt, String timestamp) throws RequestCreationException {
		return createPublishUpdateRequest(i, null, metadatalist, lt, timestamp);
	}


	public SubPublishRequest createPublishNotifyRequest(Identifier i1, Identifier i2,
			List<Metadata> mlist, MetaLifeTimeType lt, String timestamp) throws RequestCreationException {
		return new PublishNotify(i1, i2, mlist, timestamp);
	}
	
	public SubPublishRequest createPublishNotifyRequest(Identifier i1, 
			List<Metadata> mlist, MetaLifeTimeType lt, String timestamp) throws RequestCreationException {
		return createPublishNotifyRequest(i1, null, mlist, lt, timestamp);
	}
}
